#if !defined(EHNDTW_H)  // If this file was already included then
#define      EHNDTW_H   // prevent this file from being included again
 
/*********************************************************************/
/* COPYRIGHT = 5738-PC1 (C) COPYRIGHT IBM CORP 1984, 1992            */
/*   LICENSED MATERIAL - PROGRAM PROPERTY OF IBM                     */
/*   REFER TO COPYRIGHT INSTRUCTIONS FORM NUMBER G120-2083.          */
/*********************************************************************/
/*********************************************************************
 
  PURPOSE:
    This file describes the API and return codes for the
    PC Support/400 Data Translation DLL for Windows 3.x.
 
    This module includes the translation functions that need data
    conversions for transferring data from the AS/400 to the personal
    computer, and vice versa.  For both types of transfers, the
    necessary conversion depends on the type of data being transferred.
 
  ROUTINES:
    EHNDT_Bin2ToASCII6
    EHNDT_Bin4ToASCII11
    EHNDT_ASCII6ToBin2
    EHNDT_ASCII11ToBin4
    EHNDT_HexToASCII
    EHNDT_ASCIIToHex
    EHNDT_PackedToPacked
    EHNDT_DosToPacked
    EHNDT_PackedToDos
    EHNDT_PackedToASCII
    EHNDT_ASCIIToPacked
    EHNDT_ZonedToZoned
    EHNDT_ZonedToDos
    EHNDT_DosToZoned
    EHNDT_ZonedToASCII
    EHNDT_ASCIIToZoned
    EHNDT_EBCDICToEBCDIC
 
    EHNDT_GetEBCDICToASCIITable
    EHNDT_GetASCIIToEBCDICTable
    EHNDT_ASCIIToEBCDIC
    EHNDT_EBCDICToASCII
    EHNDT_ANSIToEBCDIC
    EHNDT_EBCDICToANSI
 
*******************************************************************************/
 
/* Common constants.                                                          */
 
#define  EHNDT_SUCCESS              0
 
#define  EHNDT_TRANSLATION_ERR      1
#define  EHNDT_TRUNCATION_ERR       0x6f
 
#define  EHNDT_E2A_TABLE_NOT_FOUND  0xfffc
#define  EHNDT_A2E_TABLE_NOT_FOUND  0xfffc
 
#define  EHNDT_NULLPOINTER     0xfffd   /* NULL pointer passed as parameter   */
#define  EHNDT_OVERFLOW        0xfffe   /* overflow indication                */
#define  EHNDT_MEMALLOC        0xffff   /* memory allocation failure          */
 
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_Bin2ToASCII6
 
  PURPOSE:
    This function translates a 2-byte integer stored most significant byte
    first to (exactly) 6 ASCII numeric characters.
    (The target will not be zero terminated.)
    This function can be used for translating numeric data from an
    AS/400 to ASCII.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target (6 byte) area.
 
    char _far *lpSource
      Pointer to the source (2 byte integer).
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
 
  USAGE NOTES:
    The source data is assumed to be stored with the Most Significant
    Byte first.  This is the format that the AS/400 uses and is the
    opposite of the format used by the Intel x86 processors.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_Bin2ToASCII6(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource );  /* IN  : A pointer to the source      */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_Bin4ToASCII11
 
  PURPOSE:
    This function translates a 4-byte integer stored most significant byte
    first to (exactly) 11 ASCII numeric characters.
    (The target will not be zero terminated.)
    This function can be used for translating numeric data from an
    AS/400 to ASCII.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target (11 byte) area.
 
    char _far *lpSource
      Pointer to the source (4 byte integer).
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
 
  USAGE NOTES:
    The source data is assumed to be stored with the Most Significant
    Byte first.  This is the format that the AS/400 uses and is the
    opposite of the format used by the Intel x86 processors.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_Bin4ToASCII11(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource );  /* IN  : A pointer to the source      */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCII6ToBin2
 
  PURPOSE:
    This function translates (exactly) 6 ASCII numeric characters
    to a 2-byte integer stored most significant byte first.
    (The source string is not expected to be zero-terminated.)
    This function can be used for translating ASCII numeric data
    to the AS/400 integer format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target (2 byte integer).
 
    char _far *lpSource
      Pointer to the source (6 byte ASCII).
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    EHNDT_OVERFLOW    - Overflow error.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The target data will be stored with the Most Significant Byte first.
    This is the format that the AS/400 uses and is the opposite of the
    format used by the Intel x86 processors.
 
    Valid formats for the ASCII source data are as follows:
 
       [blankspaces][sign][blankspaces][digits]
    or [sign][blankspaces][digits][blankspaces]
 
    examples:
      " + 123"
      "- 123 "
      " +123 "
      "   123"
      "  -123"
      "+123  "
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCII6ToBin2(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource );  /* IN  : A pointer to the source      */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCII11ToBin4
 
  PURPOSE:
    This function translates (exactly) 11 ASCII numeric characters
    to a 4-byte integer stored most significant byte first.
    (The source string is not expected to be zero-terminated.)
    This function can be used for translating ASCII numeric data
    to the AS/400 integer format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target (4 byte integer).
 
    char _far *lpSource
      Pointer to the source (11 byte ASCII).
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    EHNDT_OVERFLOW    - Overflow error.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The target data will be stored with the Most Significant Byte first.
    This is the format that the AS/400 uses and is the opposite of the
    format used by the Intel x86 processors.
 
    Valid formats for the ASCII source data are as follows:
 
       [blankspaces][sign][blankspaces][digits]
    or [sign][blankspaces][digits][blankspaces]
 
    examples:
      "   +    123"
      "-    123   "
      "     +123  "
      "        123"
      "       -123"
      "+123       "
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCII11ToBin4(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource );  /* IN  : A pointer to the source      */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_HexToASCII
 
  PURPOSE:
    This function translates binary data to the ASCII hex representation.
    Two ASCII characters are stored in the target for each byte of source data.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target (ASCII hex) data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
 
  USAGE NOTES:
    For 'length' bytes of source data 'length'*2 bytes of target data
    will be stored.  The caller must make sure that there is adequate
    space to hold the target information.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_HexToASCII(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in lpSource  */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCIIToHex
 
  PURPOSE:
    This function translates data from ASCII (hex representation) to binary.
    One byte is stored in the target for each two bytes in the source.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source (ASCII hex) data.
 
    int        length
      Number of bytes of source data to translate/2.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    For 'length' bytes of source data 'length'/2 bytes of target data
    will be stored.  The caller must make sure that there is adequate
    space to hold the target information.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCIIToHex(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in lpTarget  */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_PackedToPacked
 
  PURPOSE:
    This function translates packed decimal data to packed decimal.
    This function can be used for transferring data from the AS/400 system
    to no-conversion files, and vice versa.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    This function checks that each half-byte of the packed decimal data
    is in the range of 0 to 9.  The only exception is the last half-byte
    which contains the sign indicator.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_PackedToPacked(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_DosToPacked
 
  PURPOSE:
    This function translates data from DOS random packed format to packed
    decimal.
    This function can be used for translating data from DOS random files
    to the AS/400 system format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    This function checks that each half-byte of the packed decimal data
    is in the range of 0 to 9.  The only exception is the last half-byte
    which contains the sign indicator (which can be 0x3 or 0xb).
 
*******************************************************************************/
extern unsigned int _far _pascal EHNDT_DosToPacked(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_PackedToDos
 
  PURPOSE:
    This function translates data from packed decimal format to DOS
    random packed format.
    This function can be used for translating data from the AS/400 for use
    in DOS random format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    This function checks that each half-byte of the packed decimal data
    is in the range of 0 to 9.  The only exception is the last half-byte
    which contains the sign indicator (which can be 0-9, 0xd, or 0xb).
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_PackedToDos(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_PackedToASCII
 
  PURPOSE:
    This function translates data from packed decimal format to ASCII
    numeric data.
    This function can be used for translating data from the AS/400 for use
    in ASCII text format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
    int        decimal_position
      Position of the decimal point.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    This function checks that each half-byte of the packed decimal data
    is in the range of 0 to 9.  The only exception is the last half-byte
    which contains the sign indicator.
 
    0 <= decimal_position < (length * 2).
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_PackedToASCII(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length,      /* IN  : number of bytes in source    */
                int decimal_position ); /* IN  : position of decimal point    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCIIToPacked
 
  PURPOSE:
    This function translates ASCII numeric data to packed decimal format.
    This function can be used for translating ASCII text data for use on the
    AS/400.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.  Must be zero terminated.
 
    int        length
      Number of bytes of target data to translate.
 
    int        decimal_position
      Position of the decimal point.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    EHNDT_OVERFLOW    - Overflow error.
    EHNDT_MEMALLOC    - Unable to allocate temporary memory.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The sign half-byte will be set to 0xd to indicate a negative
    number and hex 0xc to indicate a positive number.
 
    0 <= decimal_position < (length * 2).
 
    Valid formats for the ASCII numeric data are as follows:
 
       [blankspaces][sign][blankspaces][digits]
    or [sign][blankspaces][digits][blankspaces]
    or [sign][digits][.digits][blankspaces]
    or [blankspaces][sign][digits][.digits][blankspaces]
 
    examples:
      "   +  123\0"
      "- 123   \0"
      "     +123  \0"
      "    123\0"
      "       -12.3\0"
      "+1.23       \0"
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCIIToPacked(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length,      /* IN  : number of bytes in target    */
                int decimal_position ); /* IN  : position of decimal point    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ZonedToZoned
 
  PURPOSE:
    This function translates data from zoned decimal format to zoned decimal.
    This function can be used for translating data from the AS/400 for use
    in no-conversion files and vice-versa.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The high half of the last byte of the zoned data indicates the sign
    of the number.  If the high half-byte is 0xb or 0xb then a negative
    number is indicated, any other value indicates a positive number.
 
    This function checks that the high half of each byte of zoned data
    must be 0xf except for the last byte.  The low half of each byte
    of zoned data must be in the range 0-9.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ZonedToZoned(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ZonedToDos
 
  PURPOSE:
    This function translates data from EBCDIC zoned decimal format to
    DOS random zoned decimal format.
    This function can be used for translating data from the AS/400 for use
    in DOS random files.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The left half-byte (0xf) in the EBCDIC zoned decimal data will be
    converted to 0x3 in the left half-byte of the DOS random zoned
    decimal data except for the last byte (sign).
 
    The high half of the last byte of the EBCDIC zoned decimal data indicates
    the sign of the number.  If the high half-byte is 0xb or 0xb then a
    negative number is indicated, any other value indicates a positive number.
 
    This function checks that the high half of each byte of EBCDIC zoned
    decimal data must be 0xf except for the last byte.  The low half of
    each byte of EBCDIC zoned decimal data must be in the range 0-9.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ZonedToDos(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_DosToZoned
 
  PURPOSE:
    This function translates data from DOS random zoned decimal format to
    EBCDIC zoned decimal.
    This function can be used for translating data from DOS random files
    for use on the AS/400.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The left half of each byte (0x3) in the DOS random zoned decimal
    format will be converted to 0xf in the left half-byte of the EBCDIC
    zoned data except for the last byte (sign).
 
    This function checks that the left half of each byte in the DOS
    random zoned decimal data must be 0x3 except for the last byte.
    The high half of the last byte must be 0x3 or 0xb.
    The right half of each byte in the DOS random zoned decimal data
    must be in the range 0-9.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_DosToZoned(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of bytes in source    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ZonedToASCII
 
  PURPOSE:
    This function translates EBCDIC zoned decimal data to ASCII numeric format.
    This function can be used for translating data from the AS/400 for use
    in ASCII text format.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of source data to translate.
 
    int        decimal_position
      Position of the decimal point.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    EHNDT_OVERFLOW    - Overflow error.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The high half of the last byte of the zoned data indicates the sign
    of the number.  If the high half-byte is 0xb or 0xb then a negative
    number is indicated, any other value indicates a positive number.
 
    This function checks that the high half of each byte of zoned data
    must be 0xf except for the last byte.  The low half of each byte
    of zoned data must be in the range 0-9.
 
    0 <= decimal_position < length.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ZonedToASCII(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length,      /* IN  : number of bytes in source    */
                int decimal_position ); /* IN  : position of decimal point    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCIIToZoned
 
  PURPOSE:
    This function translates ASCII numeric data to EBCDIC zoned decimal format.
    This function can be used for translating ASCII text data for use on the
    AS/400.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.  Must be zero terminated.
 
    int        length
      Number of bytes of target data to translate.
 
    int        decimal_position
      Position of the decimal point.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    EHNDT_OVERFLOW    - Overflow error.
    EHNDT_MEMALLOC    - Unable to allocate temporary memory.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
    The sign half-byte will be set to 0xd to indicate a negative
    number and hex 0xc to indicate a positive number.
 
    0 <= decimal_position <= length.
 
    Valid formats for the ASCII numeric data are as follows:
 
       [blankspaces][sign][blankspaces][digits]
    or [sign][blankspaces][digits][blankspaces]
    or [sign][digits][.digits][blankspaces]
    or [blankspaces][sign][digits][.digits][blankspaces]
 
    examples:
      "   +  123\0"
      "- 123   \0"
      "     +123  \0"
      "    123\0"
      "       -12.3\0"
      "+1.23       \0"
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCIIToZoned(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length,      /* IN  : number of bytes in output    */
                int decimal_position ); /* IN  : position of decimal point    */
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_EBCDICToEBCDIC
 
  PURPOSE:
    This function 'translates' (copies unless character value less than
    0x40 is encountered) EBCDIC data to EBCDIC.
 
  PARAMETERS:
    HWND       hWnd
      The caller's window handle.
 
    char _far *lpTarget
      Pointer to the target data.
 
    char _far *lpSource
      Pointer to the source data.
 
    int        length
      Number of bytes of target data to translate.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS     - Ok.
    EHNDT_NULLPOINTER - NULL pointer was passed by caller.
    other             - Offset of the first untranslated character plus one.
 
  USAGE NOTES:
    The caller must make sure that there is adequate space to hold the
    target information.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_EBCDICToEBCDIC(
                HWND       hWnd,        /* IN  : The caller's window handle   */
                char _far *lpTarget,    /* OUT : A pointer to the target      */
                char _far *lpSource,    /* IN  : A pointer to the source      */
                int        length );    /* IN  : number of EBCDIC bytes       */
 
/******************************************************************************
  EXTERNAL ENTRY POINT:
    EHNDT_GetASCIIToEBCDICTable
 
  PURPOSE:
    Returns a pointer to the router's ASCII (OEM codepage) to EBCDIC
    translation table.
 
  PARAMETERS:
    HWND       hWnd
      Window handle to the application's window.
 
  RETURN VALUE: LPSTR
    Returns a pointer to the table.
    If the router is not loaded, NULL is returned.
 
  USAGE NOTES:
    Use this function to get the pointer to the table so your application
    can translate ASCII data to EBCDIC.
*******************************************************************************/
extern LPSTR far pascal EHNDT_GetASCIIToEBCDICTable( HWND hWnd );
 
 
/******************************************************************************
  EXTERNAL ENTRY POINT:
    EHNDT_GetEBCDICToASCIITable
 
  PURPOSE:
    Returns a pointer to the router's EBCDIC to ASCII (OEM codepage)
    translation table.
 
  PARAMETERS:
    HWND       hWnd
      Window handle to the application's window.
 
  RETURN VALUE: LPSTR
    Returns a pointer to the table.
    If the router is not loaded, NULL is returned.
 
  USAGE NOTES:
    Use this function to get the pointer to the table so your application
    can translate EBCDIC data to ASCII.
*******************************************************************************/
extern LPSTR _far _pascal EHNDT_GetEBCDICToASCIITable( HWND hWnd );
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_EBCDICToASCII
 
  PURPOSE:
    Translate an EBCDIC string to ASCII (OEM codepage).
 
  PARAMETERS:
    HWND       hWnd
      Caller's Windows handle.
 
    LPSTR      lpsSource
      Pointer to source string.
 
    LPSTR      lpsTarget
      Pointer to target string.
 
    unsigned int wSource
      Length of source string (number of bytes to translate).
 
    LPWORD     lpwTarget
      Pointer to word variable containing the size of the target buffer.
      This variable will be updated with the total number of translated
      characters in the target buffer.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS
    EHNDT_E2A_TABLE_NOT_FOUND
 
  USAGE NOTES:
    The source and target should not be pointed to the same string.  The
    source string is not modified.  The size of the target buffer must
    be specified in the variable pointed by the pointer lpwTarget.  If
    the target string is not large enough to contain the translated
    string, then translation stops at the end of the target string.
    If the target string is larger than required, it is then blank
    filled to the end of the string.  The total number of translated
    characters in the target buffer is returned to the caller.
 
    This routine translates from EBCDIC to ASCII based on the translation
    table loaded by the PC Support router.  This is the equivalent of
    the Windows OEM character set.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_EBCDICToASCII(
                HWND       hWnd,
                LPSTR      lpsSource,
                LPSTR      lpsTarget,
                unsigned int  wSource,
                LPWORD     lpwTarget);
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ASCIIToEBCDIC
 
  PURPOSE:
    Translate an ASCII (OEM codepage) string to EBCDIC.
 
  PARAMETERS:
    HWND       hWnd
      Caller's Windows handle.
 
    LPSTR      lpsSource
      Pointer to source string.
 
    LPSTR      lpsTarget
      Pointer to target string.
 
    unsigned int wSource
      Length of source string (number of bytes to translate).
 
    LPWORD     lpwTarget
      Pointer to word variable containing the size of the target buffer.
      This variable will be updated with the total number of translated
      characters in the target buffer.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS
    EHNDT_A2E_TABLE_NOT_FOUND
 
  USAGE NOTES:
    The source and target should not be pointed to the same string.  The
    source string is not modified.  The size of the target buffer must
    be specified in the variable pointed by the pointer lpwTarget.  If
    the target string is not large enough to contain the translated
    string, then translation stops at the end of the target string.
    If the target string is larger than required, it is then blank
    filled to the end of the string.  The total number of translated
    characters in the target buffer is returned to the caller.
 
    This routine translates from ASCII to EBCDIC based on the translation
    table loaded by the PC Support router.  This is the equivalent of
    the Windows OEM character set.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ASCIIToEBCDIC(
                HWND       hWnd,
                LPSTR      lpsSource,
                LPSTR      lpsTarget,
                unsigned int  wSource,
                LPWORD     lpwTarget );
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_EBCDICToANSI
 
  PURPOSE:
    Translate an EBCDIC string to the Windows ANSI codepage.
 
  PARAMETERS:
    HWND       hWnd
      Caller's Windows handle.
 
    LPSTR      lpsSource
      Pointer to source string.
 
    LPSTR      lpsTarget
      Pointer to target string.
 
    unsigned int wSource
      Length of source string (number of bytes to translate).
 
    LPWORD     lpwTarget
      Pointer to word variable containing the size of the target buffer.
      This variable will be updated with the total number of translated
      characters in the target buffer.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS
    EHNDT_E2A_TABLE_NOT_FOUND
 
  USAGE NOTES:
    The source and target should not be pointed to the same string.  The
    source string is not modified.  The size of the target buffer must
    be specified in the variable pointed by the pointer lpwTarget.  If
    the target string is not large enough to contain the translated
    string, then translation stops at the end of the target string.
    If the target string is larger than required, it is then blank
    filled to the end of the string.  The total number of translated
    characters in the target buffer is returned to the caller.
 
    This routine translates by from EBCDIC to ASCII by using the translation
    table loaded by the PC Support router.  An OEM to ANSI translation
    is then done before returning to the caller.
 
*******************************************************************************/
extern unsigned int _far _pascal EHNDT_EBCDICToANSI(
                HWND       hWnd,
                LPSTR      lpsSource,
                LPSTR      lpsTarget,
                unsigned int  wSource,
                LPWORD     lpwTarget);
 
/******************************************************************************
 
  EXTERNAL ROUTINE:
    EHNDT_ANSIToEBCDIC
 
  PURPOSE:
    Translate a string in the Windows ANSI codepage to EBCDIC.
 
  PARAMETERS:
    HWND       hWnd
      Caller's Windows handle.
 
    LPSTR      lpsSource
      Pointer to source string.
 
    LPSTR      lpsTarget
      Pointer to target string.
 
    unsigned int wSource
      Length of source string (number of bytes to translate).
 
    LPWORD     lpwTarget
      Pointer to word variable containing the size of the target buffer.
      This variable will be updated with the total number of translated
      characters in the target buffer.
 
  RETURN VALUE: unsigned int
    EHNDT_SUCCESS
    EHNDT_A2E_TABLE_NOT_FOUND
    EHNDT_MEMALLOC
 
  USAGE NOTES:
    The source and target should not be pointed to the same string.  The
    source string is not modified.  The size of the target buffer must
    be specified in the variable pointed by the pointer lpwTarget.  If
    the target string is not large enough to contain the translated
    string, then translation stops at the end of the target string.
    If the target string is larger than required, it is then blank
    filled to the end of the string.  The total number of translated
    characters in the target buffer is returned to the caller.
 
    This routine performs an ANSI to OEM translation before translating
    the string into EBCDIC.
 
*******************************************************************************/
extern unsigned int _far _pascal  EHNDT_ANSIToEBCDIC(
                HWND       hWnd,
                LPSTR      lpsSource,
                LPSTR      lpsTarget,
                unsigned int  wSource,
                LPWORD     lpwTarget );
 
#endif
